@@ -15,7 +15,7 @@
 #
 
 print_separator_line ()  {
-	echo "-=============================================================-"
+	echo "-=====================================================================-"
 }
 
 dry_run_information_message ()  {
@@ -34,7 +34,7 @@ no_personal_information_message () {
 #
 # Pozilla has got also releases :-)
 # 
-export POZILLA_RELEASE=5.2
+export POZILLA_RELEASE=5.5
 
 #
 # Here we do define the corresponding i18n mailing list which should also get
@@ -65,6 +65,11 @@ export LC_ALL=C
 #
 export PO_DIR="."
 
+#
+# Start the pozilla.sh internal timer with the seconds argument by now.
+#
+POZILLA_SH_TIMER_START=`date +%s`
+
 #
 # Check for all necessary applications for pozilla.sh.
 #
@@ -161,6 +166,7 @@ do
 	echo "-D --dry-run      Don't send any EMails, create statistics (implies -S)"
 	echo "-N --no-list      Don't send any EMails to the list"
 	echo "-n --no-personal  Don't send personal EMails to the last translators"
+	echo "-t --timer-stats  Print pozilla.sh working seconds statistic at the end"
 	echo "-v --version      Version informations"
 	echo "-h --help         This help screen"
 	print_separator_line
@@ -207,6 +213,10 @@ do
 		export NO_LIST=yes
 	fi
 	;;
+	-t|--timer-stats)
+	shift 1
+		export TIMER_STATS=yes
+	;;
 	-o|--output-file)
 	shift 1
 		if test "file$1" = "file" ; then
@@ -827,9 +837,9 @@ echo -e "$STAT_TABLE" >> $BODY_FILE
 echo "" >> $BODY_FILE
 echo "--" >> $BODY_FILE
 echo "This is a mail send by Pozilla R $POZILLA_RELEASE." >> $BODY_FILE
-echo "For questions concerning Pozilla or your translator's faith" >> $BODY_FILE
-echo "- the po-files - send a mail to Fatih Demir <kabalak@gtranslator.org>" >> $BODY_FILE
-echo "Thanks." >> $BODY_FILE
+echo "For questions concerning Pozilla or your translator's faith -- the po files --" >> $BODY_FILE
+echo "   send an EMail to Fatih Demir <kabalak@gtranslator.org>." >> $BODY_FILE
+echo "Thanks for using Pozilla!" >> $BODY_FILE
 
 #
 # Send the mail to the address(es).
@@ -859,6 +869,23 @@ if test "&$PRINT_TABLE" = "&yes" ; then
 	fi
 fi
 
+#
+# Stop our internal timer by now -- we should know now how many seconds we did
+#  work for the current call.
+#
+POZILLA_SH_TIMER_STOP=`date +%s`
+POZILLA_SH_WORKING_TIME=$[ $POZILLA_SH_TIMER_STOP - $POZILLA_SH_TIMER_START ]
+
+#
+# If we should print a small working information about our "working seconds"
+#  then it's now the best place to do so.
+#
+if test "say_$TIMER_STATS" = "say_yes" ; then
+	print_separator_line
+	echo "  pozilla.sh R $POZILLA_RELEASE worked $POZILLA_SH_WORKING_TIME seconds long for you."
+	print_separator_line
+fi
+
 #
 # Recover the old LANG environment flags.
 #
