@@ -1,6 +1,7 @@
 /*
- * (C) 2001 	Fatih Demir <kabalak@gtranslator.org>
- *		Kevin Vandersloot <kfv101@psu.edu>
+ * (C) 2001-2002 	Fatih Demir <kabalak@gtranslator.org>
+ *			Gediminas Paulauskas <menesis@gtranslator.org>
+ *			Kevin Vandersloot <kfv101@psu.edu>
  *
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -51,6 +52,13 @@
 #include <gal/e-table/e-tree-scrolled.h>
 #include <gal/e-table/e-tree-memory-callbacks.h>
 
+/*
+ * We're now defining the highlighting colors once here at the top via macros.
+ */
+#define TABLE_FUZZY_COLOR "#ff0000"
+#define TABLE_UNTRANSLATED_COLOR "#a7453e"
+#define TABLE_TRANSLATED_COLOR NULL
+
 /*
  * Create the ETableExtras for our messages table.
  */
@@ -99,11 +107,29 @@ typedef struct
 	gchar	*translated;
 } GtrMessagesTableColors;
 
+/*
+ * Another own structure for the translation retrieval.
+ */
+typedef struct
+{
+	GtrMsg		*message;
+	gchar		*found_translation;
+	gboolean	 replace;
+} GtrTranslationRetrieval;
+
 /*
  * A new kind of popup menu for our beloved messages table.
  */
 static gint tree_popup_menu(ETree *tree, int row, ETreePath path, int column,
-	GdkEvent *event);
+	                    GdkEvent *event);
+static void row_selected (ETree *et, int row, ETreePath node, int column,
+		          gpointer data);
+
+/*
+ * An own insertion callback for the messages table's popup menu to insert
+ *  the found, fitting translation from the learn buffer.
+ */
+static void insert_translation(GtkWidget *widget, gpointer insertion_kind);
 
 /*
  * Global variables
@@ -119,20 +145,24 @@ ETableExtras *tree_extras;
 
 GtrMessagesTableColors *messages_table_colors;
 
+GtrTranslationRetrieval *retrieval=NULL;
+
 /*
- * hash table to associate an ETreePath with each message. Used
+ * Hash table to associate an ETreePath with each message. Used
  * in update_row to determine the node given a message that has been
  * updated
  */
-GHashTable *hash_table=NULL;	
+GHashTable *hash_table=NULL;
 
 /*
  * Pops up on a right click in the messages table -- should show any found 
  *  translation from the learn buffer.
  */
-static gint tree_popup_menu(ETree *tree, int row, ETreePath path, int column,
-	GdkEvent *event)
+gint tree_popup_menu(ETree *tree, int row, ETreePath path, int column,
+	             GdkEvent *event)
 {
+	row_selected(tree, row, path, column, NULL);
+		
 	if(event->button.button==3)
 	{
 		GtrMsg *message=NULL;
@@ -140,10 +170,11 @@ static gint tree_popup_menu(ETree *tree, int row, ETreePath path, int column,
 		message=e_tree_memory_node_get_data(tree_memory, path);
 
 		/*
-		 * Check if we're on an untranslated message before operating 
-		 *  any further.
+		 * Check if we're on an untranslated or fuzzy message before 
+		 *  operating any further.
 		 */
-		if(message && message->msgid && !message->msgstr)
+		if(message && message->msgid && (!message->msgstr ||
+			message->status & GTR_MSG_STATUS_FUZZY))
 		{
 			GtkWidget	*menu=NULL;
 			GtkWidget 	*menu_item=NULL;
@@ -160,16 +191,48 @@ static gint tree_popup_menu(ETree *tree, int row, ETreePath path, int column,
 			if(found_str)
 			{
 				GtkWidget	*explanatory_menu_item=NULL;
+				GtkWidget	*edit_sub_menu=NULL;
+				GtkWidget	*imt_menu_item, *separator, *ipmt_menu_item=NULL;
 
 				explanatory_menu_item=gtk_menu_item_new_with_label(_("Appropriate match:"));
+
 				gtk_widget_show(explanatory_menu_item);
 				gtk_menu_append(GTK_MENU(menu), explanatory_menu_item);
 
 				menu_item=gtk_menu_item_new_with_label(found_str);
+
+				edit_sub_menu=gtk_menu_new();
+
+				imt_menu_item=gtk_menu_item_new_with_label(_("Insert matching translation"));
+				separator=gtk_menu_item_new();
+				ipmt_menu_item=gtk_menu_item_new_with_label(_("Take as translation"));
+				
+				gtk_widget_show(imt_menu_item);
+				gtk_menu_append(GTK_MENU(edit_sub_menu), imt_menu_item);
+
+				gtk_widget_show(separator);
+				gtk_menu_append(GTK_MENU(edit_sub_menu), separator);
+
+				gtk_widget_show(ipmt_menu_item);
+				gtk_menu_append(GTK_MENU(edit_sub_menu), ipmt_menu_item);
+
+				gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_item), edit_sub_menu);
+
+				retrieval=g_new0(GtrTranslationRetrieval, 1);
+				retrieval->found_translation=found_str;
+				retrieval->message=message;
+
+				gtk_signal_connect(GTK_OBJECT(imt_menu_item), "activate",
+					GTK_SIGNAL_FUNC(insert_translation), GINT_TO_POINTER(1));
+
+				gtk_signal_connect(GTK_OBJECT(ipmt_menu_item), "activate",
+					GTK_SIGNAL_FUNC(insert_translation), GINT_TO_POINTER(2));
 			}
 			else
 			{
-				menu_item=gtk_menu_item_new_with_label(_("Found nothing appropriate in the personal learn buffer."));
+				menu_item=gtk_menu_item_new_with_label(
+					_("Found nothing appropriate in\n\
+ the personal learn buffer."));
 
 			}
 
@@ -191,6 +254,45 @@ static gint tree_popup_menu(ETree *tree, int row, ETreePath path, int column,
 	return TRUE;
 }
 
+/*
+ * Insert the found translation
+ */
+static void insert_translation(GtkWidget *widget, gpointer insertion_kind)
+{
+	retrieval->replace=(GPOINTER_TO_INT(insertion_kind) == 2);
+
+	if(retrieval->message && retrieval->found_translation)
+	{
+		if(retrieval->replace)
+		{
+			GTR_FREE(retrieval->message->msgstr);
+			retrieval->message->msgstr=g_strdup(retrieval->found_translation);
+		}
+		else
+		{
+			if(!retrieval->message->msgstr)
+			{
+				retrieval->message->msgstr=g_strdup(retrieval->found_translation);
+			}
+			else
+			{
+				gchar *oldstr=retrieval->message->msgstr;
+				retrieval->message->msgstr=g_strconcat(oldstr, retrieval->found_translation, NULL);
+				GTR_FREE(oldstr);
+			}
+		}
+
+		gtranslator_message_status_set_fuzzy(retrieval->message, FALSE);
+		retrieval->message->status |= GTR_MSG_STATUS_TRANSLATED;
+		gtranslator_message_show(retrieval->message);
+		gtranslator_messages_table_update_message_status(retrieval->message);
+		gtranslator_messages_table_update_row(retrieval->message);
+
+		GTR_FREE(retrieval->found_translation);
+		GTR_FREE(retrieval);
+	}
+}
+
 /*
  * Initialize and set up the generally used messages table colors.
  */
@@ -205,8 +307,6 @@ static void read_messages_table_colors()
 	{
 		gchar	*value;
 		
-		gtranslator_config_init();
-		
 		value=gtranslator_config_get_string("colors/messages_table_untranslated");
 
 		if(value && value[0]=='#')
@@ -216,7 +316,7 @@ static void read_messages_table_colors()
 		}
 		else
 		{
-			messages_table_colors->untranslated=g_strdup("#a7453e");
+			messages_table_colors->untranslated=g_strdup(TABLE_UNTRANSLATED_COLOR);
 		}
 
 		value=gtranslator_config_get_string("colors/messages_table_fuzzy");
@@ -228,7 +328,7 @@ static void read_messages_table_colors()
 		}
 		else
 		{
-			messages_table_colors->fuzzy=g_strdup("#ff0000");
+			messages_table_colors->fuzzy=g_strdup(TABLE_FUZZY_COLOR);
 		}
 
 		value=gtranslator_config_get_string("colors/messages_table_translated");
@@ -240,16 +340,14 @@ static void read_messages_table_colors()
 		}
 		else
 		{
-			messages_table_colors->translated=NULL;
+			messages_table_colors->translated=TABLE_TRANSLATED_COLOR;
 		}
-
-		gtranslator_config_close();
 	}
 	else
 	{
-		messages_table_colors->untranslated=g_strdup("#a7453e");
-		messages_table_colors->fuzzy=g_strdup("#ff0000");
-		messages_table_colors->translated=NULL;
+		messages_table_colors->untranslated=g_strdup(TABLE_UNTRANSLATED_COLOR);
+		messages_table_colors->fuzzy=g_strdup(TABLE_FUZZY_COLOR);
+		messages_table_colors->translated=TABLE_TRANSLATED_COLOR;
 	}
 }
 
@@ -545,7 +643,7 @@ static gchar *return_string_for_value_function(ETreeModel *model, int column,
 	}
 }
 
-static void
+void
 row_selected (ETree *et, int row, ETreePath node, int column, gpointer data)
 {
 	GtrMsg *message, *old_message;
@@ -651,29 +749,21 @@ GtkWidget *gtranslator_messages_table_new()
 		is_empty_function,
 		return_string_for_value_function,
 		NULL);
-	
-	e_tree_memory_set_expanded_default(E_TREE_MEMORY(tree_model), TRUE);
 
+	e_tree_memory_set_expanded_default(E_TREE_MEMORY(tree_model), TRUE);
+	
 	tree_memory=E_TREE_MEMORY(tree_model);
 
-	/* Calling gtk_widget_new here is to work around a bug in gal
-	** where e_tree_scrolled_new_from_spec is broken */
-	messages_tree=gtk_widget_new(e_tree_scrolled_get_type (),
-        	"hadjustment", NULL,
-        	"vadjustment", NULL,
-        	NULL);
-	
-	messages_tree = GTK_WIDGET(
-		e_tree_scrolled_construct_from_spec_file(
-			E_TREE_SCROLLED(messages_tree),
+	messages_tree = e_tree_scrolled_new_from_spec_file(
 			tree_model,
 			tree_extras,
-			ETSPECS_DIR "/messages-table.etspec", 
-			gtranslator_runtime_config->table_state_filename)
+			ETSPECS_DIR "/messages-table.etspec",
+			gtranslator_runtime_config->table_state_filename
 		);
+	
 
 	tree = GTK_WIDGET(e_tree_scrolled_get_tree (E_TREE_SCROLLED (messages_tree)));
-
+	
 	gtk_signal_connect(GTK_OBJECT(tree), "cursor_activated",
 		GTK_SIGNAL_FUNC(row_selected), NULL);
 	
@@ -693,6 +783,7 @@ void gtranslator_messages_table_clear(void)
 		e_tree_memory_node_remove(tree_memory, root_node);
 		/* sadly we seem to need to create a root_node or else mayhem results */
 		root_node=e_tree_memory_node_insert (tree_memory, NULL, 0, NULL);
+
 	}
 	
 	if(hash_table)
@@ -727,7 +818,7 @@ void gtranslator_messages_table_create (void)
 	
 	read_messages_table_colors();
 	hash_table=g_hash_table_new(g_direct_hash, g_direct_equal);
-	
+		
 	unknown_node = e_tree_memory_node_insert (tree_memory, root_node, 0, NULL);
 	fuzzy_node = e_tree_memory_node_insert (tree_memory, root_node, 1, NULL);
 	translated_node = e_tree_memory_node_insert (tree_memory, root_node, 2, NULL);
@@ -735,7 +826,7 @@ void gtranslator_messages_table_create (void)
 	/*
 	 * Collapse all translated entries according to the user's preference.
 	 */
-	e_tree_node_set_expanded_recurse(E_TREE(tree), translated_node, 
+	e_tree_node_set_expanded(E_TREE(tree), translated_node, 
 		!GtrPreferences.collapse_translated);
 	
 	while(list)
@@ -769,6 +860,14 @@ void gtranslator_messages_table_create (void)
 			g_hash_table_insert(hash_table, message, node); 
 		list = g_list_next(list);
 	}
+
+
+	/*
+	 * Notify the tree_model that we have been 
+	 * reconfiguring
+	 */
+	
+	e_tree_model_node_changed(tree_model, root_node);
 }
 
 /*
@@ -782,7 +881,8 @@ void gtranslator_messages_table_update_row(GtrMsg *message)
 	node=g_hash_table_lookup(hash_table, message);
 
 	if(node)
-	{
+	{	
+		e_tree_model_pre_change (tree_model);
 		e_tree_model_node_data_changed (tree_model, node);
 	}
 }
@@ -807,10 +907,10 @@ void gtranslator_messages_table_select_row(GtrMsg *message)
 		if((message->status & GTR_MSG_STATUS_TRANSLATED) &&
 			GtrPreferences.collapse_translated)
 		{
-			e_tree_node_set_expanded_recurse(E_TREE(tree), 
+			e_tree_node_set_expanded(E_TREE(tree), 
 				translated_node, TRUE);
 		}
-		
+
 		e_tree_set_cursor(E_TREE(tree), node);
 	}
 }
