@@ -51,6 +51,10 @@ GtrRuntimeConfig *gtranslator_runtime_config_new()
 		"%s/.gtranslator/files/gtranslator-temp-file",
 			g_get_home_dir());
 
+	config->check_filename=g_strdup_printf(
+		"%s/.gtranslator/files/gtranslator-check-file",
+			g_get_home_dir());
+
 	config->crash_filename=g_strdup_printf(
 		"%s/.gtranslator/files/gtranslator-crash-file",
 			g_get_home_dir());
@@ -70,12 +74,11 @@ GtrRuntimeConfig *gtranslator_runtime_config_new()
 	/*
 	 * Based on a suggestion by Pablo Saratxaga (/thanks pablo!).
 	 *
-	 * Translators: you should translate this empty string to avoid the
-	 *  usage of the mid dot ('') in the displaying routines.
-	 *
-	 *   The contents of your translation are irrelevant in this case.
+	 * Translators: you should translate this foo'sh string into something
+	 *  another than a 'Y' to avoid the usage of the mid dot ('') in the
+	 *   text displaying routines of gtranslator.
 	 */
-	if (_("")[0]=='\0')
+	if (_("Y")[0]=='Y')
 	{
 		gchar *middot=NULL;
 		gchar *encoding=NULL;
@@ -90,6 +93,10 @@ GtrRuntimeConfig *gtranslator_runtime_config_new()
 		}
 		else
 		{
+			/*
+			 * Translators: this character is used if the middle dot
+			 *  can't be used under your locale.
+			 */
 			config->special_char=_("^")[0];
 		}
         }
@@ -109,6 +116,7 @@ void gtranslator_runtime_config_free(GtrRuntimeConfig *config)
 	if(config)
 	{
 		GTR_FREE(GTR_RUNTIME_CONFIG(config)->temp_filename);
+		GTR_FREE(GTR_RUNTIME_CONFIG(config)->check_filename);
 		GTR_FREE(GTR_RUNTIME_CONFIG(config)->crash_filename);
 		GTR_FREE(GTR_RUNTIME_CONFIG(config)->backend_filename);
 		
