@@ -377,6 +377,24 @@ permission for it."),
 	return TRUE;
 }
 
+void gtranslator_parse_main(const gchar *filename);
+void open_it_anyway_callback( gint, gpointer );
+
+void open_it_anyway_callback( gint reply, gpointer filename )
+{
+	extern gboolean open_anyway;
+	
+	switch( reply ){
+		case 0: /* YES */
+			open_anyway = TRUE;
+			gtranslator_parse_main( (gchar*)filename );
+			break;
+		case 1: /* NO */
+			break;
+	}
+	g_free( filename );
+}
+
 /*
  * Check if the given file is alrady opened by gtranslator.
  */
@@ -384,6 +402,13 @@ gboolean gtranslator_utils_check_file_being_open(const gchar *filename)
 {
 	gchar *resultfilename;
 
+	extern gboolean open_anyway;
+
+	if( open_anyway ){
+		open_anyway = FALSE;
+		return( FALSE );
+	}
+
 	g_return_val_if_fail(filename!=NULL, FALSE);
 
 	resultfilename=gtranslator_config_get_string("runtime/filename");
@@ -396,17 +421,29 @@ gboolean gtranslator_utils_check_file_being_open(const gchar *filename)
 		(strlen(resultfilename)==strlen(filename)))
 	{
 		gchar *error_message;
+		gchar *fname;
+		
+		fname = g_strdup( filename );
 
 		error_message=g_strdup_printf(
-		_("The file `%s' is already open in another instance of gtranslator!\n\
-Please close the other instance of gtranslator handling `%s' currently to\n\
-re-gain access to this file (also applies for post-crash cases)."), 
-			filename, filename);
+		_("The file\n"
+		"\n"
+		"   %s\n"
+		"\n"
+		"is already open in another instance of gtranslator!\n"
+		"Please close the other instance of gtranslator handling\n"
+		"this file currently to re-gain access to this file.\n"
+		"\n"
+		"Shall fool gtranslator open this file anyway ?"), 
+		filename);
 
 		/*
-		 * Return with FALSE if the given file is already open.
+		 * Return with FALSE if the given file is already open. ???
+		 * +++++
 		 */
-		gnome_app_error(GNOME_APP(gtranslator_application), error_message);
+		/* gnome_app_error(GNOME_APP(gtranslator_application), error_message); */
+		gnome_app_question_modal( GNOME_APP(gtranslator_application), error_message,
+			open_it_anyway_callback, (gpointer)fname );
 		
 		GTR_FREE(resultfilename);
 		GTR_FREE(error_message);
